callback_c

Function callback_c 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn callback_c( camera_handle: VmbHandle_t, _stream_handle: VmbHandle_t, frame: *mut VmbFrame_t, )
Safety

This function will not propagate panics that happen in the callback, but it should print an error to stderr and then soon stop further image-ready callbacks.